@@ -36,7 +36,7 @@ class TestGroupsController(TestController):
                                                     'member_list':['user1@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(_('/groups/@group1') in response.headers['location'])
+        self.assertEqual(_('/groups/@group1'), response.headers['location'])
 
     # def test_new(self):
     #     response = self.app.get(url('new_group'))
@@ -55,7 +55,7 @@ class TestGroupsController(TestController):
                                                     'member_list':['user2@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/groups/@group2')))
+        self.assertEqual(_('/groups/@group2'), response.headers['location'])
         response = self.app.put(url('group', id='@group2', repo_id='repo1'),
                                 params=json.dumps(['user2@test.com', 'user3@test.com']),
                                 content_type='application/json')
@@ -75,7 +75,7 @@ class TestGroupsController(TestController):
                                                     'member_list':['user2@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/groups/@group3')))
+        self.assertEqual(_('/groups/@group3'), response.headers['location'])
         response = self.app.delete(url('group', id='@group3', repo_id='repo1'))
         self.assertEqual(response.status, '200 OK')
         response = self.app.get(url('groups', repo_id='repo1'))
@@ -96,7 +96,7 @@ class TestGroupsController(TestController):
                                                     'member_list':['user2@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/groups/@group4')))
+        self.assertEqual(_('/groups/@group4'), response.headers['location'])
         response = self.app.get(url('group', id='@group4', repo_id='repo1'))
         self.assertEqual(response.status, '200 OK')
         self.assertItemsEqual(json.loads(response.body),['user2@test.com'])
